@@ -423,7 +423,7 @@ void CheckParamData ( void )
 
    if ( strcmp(p_plot_param->grid, "on1") == 0 )
       {
-      if ( (gridchar1 != 'l' && gridchar1 != 'd') ||
+      if ( (gridchar1 != 'l' && gridchar1 != 'd' && gridchar1 != '.') ||
            (pchar = strchr(color_string, gridchar2)) == NULL )
          {
          ErrorDialog(error_str[11]);
