@@ -6,10 +6,11 @@
 *    RequestDialog
 *    ErrorDialog
 *    MessageDialog
+*    QuestionDialog
 *
 * General-purpose dialogs.
 *
-* Copyright  2008 Spencer A. Buckner
+* Copyright  2008-2009 Spencer A. Buckner
 * http://savannah.gnu.org/projects/gsegrafix
 *
 * This file is part of GSEGrafix, a scientific and engineering plotting program.
@@ -56,7 +57,6 @@ void RequestDialog ( const char *prompt_str, const char *text_str, void (*callba
                                  "window-position", GTK_WIN_POS_CENTER,
                                  "resizable", FALSE,
                                  "border-width", 12,
-                                 "modal", TRUE,
                                  NULL);
 
 
@@ -110,7 +110,8 @@ void RequestDialog ( const char *prompt_str, const char *text_str, void (*callba
 
    /* Add hbox, entry box and hbutton box to vbox; add vbox to window */
    gtk_container_add(GTK_CONTAINER(vbox), GTK_WIDGET(hbox));
-   gtk_box_pack_start_defaults(GTK_BOX(vbox), GTK_WIDGET(entry_box));
+   if ( text_str != NULL )
+      gtk_box_pack_start_defaults(GTK_BOX(vbox), GTK_WIDGET(entry_box));
    gtk_container_add(GTK_CONTAINER(vbox), GTK_WIDGET(hbuttonbox));
    gtk_container_add(GTK_CONTAINER(dialog_request), GTK_WIDGET(vbox));
 
@@ -134,7 +135,6 @@ void RequestDialog ( const char *prompt_str, const char *text_str, void (*callba
    /* Show dialog */
    gtk_widget_grab_focus(GTK_WIDGET(entry_box));
    gtk_widget_show_all(GTK_WIDGET(dialog_request));
-   gtk_window_set_modal(dialog_request, TRUE);
    gtk_window_present(dialog_request);
 
    gtk_main();
@@ -161,7 +161,6 @@ void ErrorDialog ( const char *message_str )
                                "window-position", GTK_WIN_POS_CENTER,
                                "resizable", FALSE,
                                "border-width", 12,
-                               "modal", TRUE,
                                NULL);
 
 
@@ -221,7 +220,6 @@ void ErrorDialog ( const char *message_str )
    /* Show dialog */
    gtk_widget_grab_focus(GTK_WIDGET(ok_button));
    gtk_widget_show_all(GTK_WIDGET(dialog_error));
-   gtk_window_set_modal(dialog_error, TRUE);
    gtk_window_present(dialog_error);
 
    gtk_main();
@@ -248,7 +246,6 @@ void MessageDialog ( const char *message_str )
                                  "window-position", GTK_WIN_POS_CENTER,
                                  "resizable", FALSE,
                                  "border-width", 12,
-                                 "modal", TRUE,
                                  NULL);
 
 
@@ -308,10 +305,68 @@ void MessageDialog ( const char *message_str )
    /* Show dialog */
    gtk_widget_grab_focus(GTK_WIDGET(ok_button));
    gtk_widget_show_all(GTK_WIDGET(dialog_message));
-   gtk_window_set_modal(dialog_message, TRUE);
    gtk_window_present(dialog_message);
 
    gtk_main();
 
    return;
    }
+
+
+void QuestionDialog ( const char *question_str, void (*callback) )
+   {
+   /* Declare variables */
+   GtkDialog *dialog_question;
+   GtkHBox *hbox;
+   GtkImage *image;
+   GtkLabel *label;
+
+
+   /* Create dialog */
+   dialog_question = GTK_DIALOG(gtk_dialog_new_with_buttons("Question",
+                                                            NULL,
+                                                            GTK_DIALOG_DESTROY_WITH_PARENT,
+                                                            "_Cancel", GTK_RESPONSE_CANCEL,
+                                                            "_OK", GTK_RESPONSE_OK,
+                                                            NULL));
+
+
+   /* Create packing box */
+   hbox = g_object_new(GTK_TYPE_HBOX,
+                       "border-width", 8,
+                       NULL);
+
+
+   /* Create image */
+   image = g_object_new(GTK_TYPE_IMAGE,
+                        "stock", GTK_STOCK_DIALOG_QUESTION,
+                        "icon-size", GTK_ICON_SIZE_DIALOG,
+                        NULL);
+
+
+   /* Create label */
+   label = g_object_new(GTK_TYPE_LABEL,
+                        "label", question_str,
+                        NULL);
+
+
+   /* Add image and label to hbox and add hbox to dialog */
+   gtk_box_pack_start(GTK_BOX(hbox), GTK_WIDGET(image), FALSE, FALSE, 0);
+   gtk_box_pack_start(GTK_BOX(hbox), GTK_WIDGET(label), TRUE, TRUE, 0);
+   gtk_box_pack_start(GTK_BOX(dialog_question->vbox), GTK_WIDGET(hbox), FALSE, FALSE, 0);
+
+
+   /* Connect signal handler */
+   g_signal_connect(dialog_question, "response", G_CALLBACK(callback), NULL);
+   g_signal_connect(dialog_question, "response", G_CALLBACK(gtk_main_quit), NULL);
+   g_signal_connect_swapped(dialog_question, "response", G_CALLBACK(gtk_widget_destroy), dialog_question);
+   g_signal_connect(dialog_question, "delete-event", G_CALLBACK(gtk_main_quit), NULL);
+
+
+   /* Show dialog */
+   gtk_widget_show_all(GTK_WIDGET(dialog_question));
+   gtk_main();
+
+   return;
+   }
+
