@@ -4,7 +4,7 @@
 *
 * Plots 3-dimensional contour data for polygons that are not truncated.
 *
-* Copyright  2008 Spencer A. Buckner
+* Copyright  2008-2009 Spencer A. Buckner
 * http://savannah.gnu.org/projects/gsegrafix
 *
 * This file is part of GSEGrafix, a scientific and engineering plotting program.
@@ -29,7 +29,7 @@
 #include "gsegraf.h"
 
 
-void DrawContours3d ( double *xpoints, double *ypoints, double *zpoints )
+void DrawContours3d ( int icontour, double *xpoints, double *ypoints, double *zpoints )
    {
    /* Declare variables */
    int i, j, ic, nc, nxvalues, nyvalues, nzvalues, flag;
@@ -366,7 +366,7 @@ void DrawContours3d ( double *xpoints, double *ypoints, double *zpoints )
          line = gnome_canvas_item_new(group,
                                       GNOME_TYPE_CANVAS_LINE,
                                       "points", points,
-                                      "fill_color_rgba", 0x000000FF,
+                                      "fill_color_rgba", contourcolors[icontour-1],
                                       "width_pixels", 1,
                                       NULL);
          }
