@@ -359,6 +359,19 @@ void DrawLegend ( void )
             }
 
 
+         /* Draw dotted line */
+         else if ( stylechar1[iplot-1] == '.' )
+            {
+            points = gnome_canvas_points_new(2);
+            points->coords[0] = xanchor_symbol;
+            points->coords[1] = yanchor_symbol + yinc1*(iplot - 1) + yinc2;
+            points->coords[2] = xanchor_symbol + 60.0;
+            points->coords[3] = yanchor_symbol + yinc1*(iplot - 1) + yinc2;
+            DrawDottedLine(points, fill_colors_rgba[iplot-1], stylesizes[iplot-1]);
+            gnome_canvas_points_unref(points);
+            }
+
+
          /* Draw symbols in symbol_string1 ("cCtTsSiIpPhH") */
          else if ( (pchar = strchr(symbol_string1, stylechar1[iplot-1])) != NULL )
             {
