@@ -5,6 +5,7 @@
 * Contains functions:
 *    DrawLine
 *    DrawDashedLine
+*    DrawDottedLine
 *    DrawCircle
 *    DrawTriangle
 *    DrawSquare
@@ -110,7 +111,6 @@ void DrawDashedLine ( GnomeCanvasPoints *points, guint32 fill_color_rgba, unsign
       free(length);
       return;
       }
-
    else if ( length_total <= dash )
       {
       line = gnome_canvas_item_new(group,
@@ -127,13 +127,13 @@ void DrawDashedLine ( GnomeCanvasPoints *points, guint32 fill_color_rgba, unsign
 
 
    /* Recalculate dash and space lengths */
-   inc = dash + space;
-   fspace = space/inc;
+   inc = dash + space_dash;
+   fspace = space_dash/inc;
    if ( sqrt((x[npoints-1] - x[0])*(x[npoints-1] - x[0]) +
-             (y[npoints-1] - y[0])*(y[npoints-1] - y[0])) >= space )
+             (y[npoints-1] - y[0])*(y[npoints-1] - y[0])) >= space_dash )
       {
       /* Line ends with dash */
-      nlines = roundint((length_total + space)/inc);
+      nlines = roundint((length_total + space_dash)/inc);
       inc = length_total/(nlines - fspace);
       factor = length_total + fspace*inc;
       }
@@ -204,6 +204,68 @@ void DrawDashedLine ( GnomeCanvasPoints *points, guint32 fill_color_rgba, unsign
    }
 
 
+void DrawDottedLine ( GnomeCanvasPoints *points, guint32 fill_color_rgba, unsigned int size )
+   {
+   /* Declare variables */
+   int i, npoints, ndots;
+   double *x, *y, *length, length_total, inc, inc_calc, length_interp, xinterp, yinterp;
+
+
+   /* Check size */
+   if ( size == 0 )
+      return;
+
+
+   /* Calculate line length */
+   npoints = points->num_points;
+   x = malloc(npoints*sizeof(double));
+   y = malloc(npoints*sizeof(double));
+   length = malloc(npoints*sizeof(double));
+   x[0] = points->coords[0];
+   y[0] = points->coords[1];
+   length[0] = 0.0;
+   for ( i=1; i<npoints; i++ )
+      {
+      x[i] = points->coords[2*i];
+      y[i] = points->coords[2*i+1];
+      length[i] = length[i-1] +
+                  sqrt((x[i] - x[i-1])*(x[i] - x[i-1]) +
+                       (y[i] - y[i-1])*(y[i] - y[i-1]));
+      }
+   length_total = length[npoints-1];
+
+
+   /* Check line length */
+   inc = space_dot + size;
+   if ( length_total < inc )
+      {
+      free(x);
+      free(y);
+      free(length);
+      return;
+      }
+
+
+   /* Calculate number of dots */
+   ndots = roundint(length_total/inc + 1.0);
+   inc_calc = length_total/(ndots - 1);
+
+
+   /* Interpolate and draw dots */
+   for ( i=1; i<=ndots; i++ )
+      {
+      length_interp = length[0] + (i - 1)*inc_calc;
+      interp1(npoints, 1, length, x, &length_interp, &xinterp);
+      interp1(npoints, 1, length, y, &length_interp, &yinterp);
+      DrawCircle(xinterp, yinterp, fill_color_rgba, fill_color_rgba, size);
+      }
+
+   free(x);
+   free(y);
+   free(length);
+   }
+
+
 void DrawCircle ( double x, double y, guint32 fill_color_rgba,
                   guint32 outline_color_rgba, unsigned int size )
    {
