@@ -423,7 +423,8 @@ gboolean EventHandler ( GtkWidget *window, GdkEvent *event )
          tick_major = (8.0/768.0)*max_dimension;
          tick_minor = 0.5*tick_major;
          dash = tick_major;
-         space = 0.5*dash;
+         space_dash = 0.5*dash;
+         space_dot = space_dash - 1.0;
 
          /* Stop coordinates display */
          flag = 0;
