@@ -11,7 +11,7 @@
 *    
 * Functions for File menu items.
 *
-* Copyright  2008 Spencer A. Buckner
+* Copyright  2008-2009 Spencer A. Buckner
 * http://savannah.gnu.org/projects/gsegrafix
 *
 * This file is part of GSEGrafix, a scientific and engineering plotting program.
@@ -354,6 +354,8 @@ void FreeMemory ( void )
    free(bin_refs);
    free(stemflags);
    free(stemvalues);
+   free(meshcolors);
+   free(contourcolors);
    free(save_filename);
    free(ndata);
    free(xdata);
