@@ -4,7 +4,7 @@
 *
 * Reads 3d data files.
 *
-* Copyright  2008 Spencer A. Buckner
+* Copyright  2008-2009 Spencer A. Buckner
 * http://savannah.gnu.org/projects/gsegrafix
 *
 * This file is part of GSEGrafix, a scientific and engineering plotting program.
@@ -31,12 +31,14 @@
 void FileRead3d ( void )
    {
    /* Declare variables */
-   int i, j, iplot, ipoints, imesh, icontour, nplots, npts, npts_total,
+   int i, j, iplot, ipoints, imesh, icontour, icolor, nplots, npts, npts_total,
        npts_total_xmesh, npts_total_ymesh, npts_total_zmesh,
        npts_total_xcontour, npts_total_ycontour, npts_total_zcontour,
+       npts_total_xcolor, npts_total_ycolor, npts_total_zcolor,
        index_filenames, index_formats, index_plot_types,
        index, nx, ny, xindex_mesh, yindex_mesh, zindex_mesh,
        xindex_contour, yindex_contour, zindex_contour,
+       xindex_color, yindex_color, zindex_color,
        ndouble, nchar, ichar;
    unsigned int size;
    double x, y, z;
@@ -58,12 +60,16 @@ void FileRead3d ( void )
    npts_total_xcontour = 0;
    npts_total_ycontour = 0;
    npts_total_zcontour = 0;
+   npts_total_xcolor = 0;
+   npts_total_ycolor = 0;
+   npts_total_zcolor = 0;
    index_filenames = 0;
    index_formats = 0;
    index_plot_types = 0;
    ipoints = 0;
    imesh = 0;
    icontour = 0;
+   icolor = 0;
    nlinebreaks = 0;
    for ( iplot=1; iplot<=nplots; iplot++ )
       {
@@ -136,6 +142,20 @@ void FileRead3d ( void )
          npts_total_zcontour = npts_total_zcontour + nx*ny;
          }
 
+      else if ( strcmp(&plot_types[index_plot_types], "color") == 0 )
+         {
+         icolor++;
+         if ( fscanf(fptr, "%d %d", &nx, &ny) != 2 )
+            {
+            ErrorDialog(error_str[1]);
+            FreeMemory();
+            exit(1);
+            }
+         npts_total_xcolor = npts_total_xcolor + nx;
+         npts_total_ycolor = npts_total_ycolor + ny;
+         npts_total_zcolor = npts_total_zcolor + nx*ny;
+         }
+
 
       /* Increment indices */
       fclose(fptr);
@@ -184,6 +204,20 @@ void FileRead3d ( void )
          }
 
 
+   /* Allocate memory for color-data arrays */
+   if ( icolor > 0 )
+      if ( (nxcolor = malloc(icolor*sizeof(int))) == NULL ||
+           (nycolor = malloc(icolor*sizeof(int))) == NULL ||
+           (xcolor = malloc(npts_total_xcolor*sizeof(double))) == NULL ||
+           (ycolor = malloc(npts_total_ycolor*sizeof(double))) == NULL ||
+           (zcolor = malloc(npts_total_zcolor*sizeof(double))) == NULL )
+         {
+         ErrorDialog(error_str[2]);
+         FreeMemory();
+         exit(1);
+         }
+
+
    /* Allocate memory for line-break index array */
    nlinebreak = NULL;
    if ( nlinebreaks > 0 )
@@ -206,9 +240,13 @@ void FileRead3d ( void )
    xindex_contour = 0;
    yindex_contour = 0;
    zindex_contour = 0;
+   xindex_color = 0;
+   yindex_color = 0;
+   zindex_color = 0;
    ipoints = 0;
    imesh = 0;
    icontour = 0;
+   icolor = 0;
    ichar = 0;
    for ( iplot=1; iplot<=nplots; iplot++ )
       {
@@ -320,6 +358,49 @@ void FileRead3d ( void )
          }
 
 
+      else if ( strcmp(&plot_types[index_plot_types], "color") == 0 )
+         {
+         icolor++;
+         if ( fscanf(fptr, "%d %d", &nxcolor[icolor-1], &nycolor[icolor-1]) != 2 )
+            {
+            ErrorDialog(error_str[1]);
+            FreeMemory();
+            exit(1);
+            }
+         nx = nxcolor[icolor-1];
+         ny = nycolor[icolor-1];
+
+         for ( i=1; i<=nx; i++ )
+            if ( fscanf(fptr, "%lf", &xcolor[xindex_color+i-1]) != 1 )
+               {
+               ErrorDialog(error_str[1]);
+               FreeMemory();
+               exit(1);
+               }
+
+         for ( j=1; j<=ny; j++ )
+            if ( fscanf(fptr, "%lf", &ycolor[yindex_color+j-1]) != 1 )
+               {
+               ErrorDialog(error_str[1]);
+               FreeMemory();
+               exit(1);
+               }
+
+         for ( i=1; i<=nx; i++ )
+            for ( j=1; j<=ny; j++ )
+               if ( fscanf(fptr, "%lf", &zcolor[zindex_color+ny*(i-1)+j-1]) != 1 )
+                  {
+                  ErrorDialog(error_str[1]);
+                  FreeMemory();
+                  exit(1);
+                  }
+
+         xindex_color = xindex_color + nx;
+         yindex_color = yindex_color + ny;
+         zindex_color = zindex_color + nx*ny;
+         }
+
+
       /* Increment indices */
       fclose(fptr);
       index_filenames = index_filenames + nfilenames[iplot-1];
