@@ -31,10 +31,10 @@
 
 
 /* Declare external variables */
-const char symbol_string[]  = "ldcCtTsSiIpPhH+xra";   /* symbol-specification characters */
-const char symbol_string1[] = "cCtTsSiIpPhH";         /* symbol-specification characters */
-const char symbol_string2[] = "+xra";                 /* symbol-specification characters */
-const char color_string[]   = "kaswrylqbfmogtnpx";    /* color-specification characters */
+const char symbol_string[]  = "ld.cCtTsSiIpPhH+xra";   /* symbol-specification characters */
+const char symbol_string1[] = "cCtTsSiIpPhH";          /* symbol-specification characters */
+const char symbol_string2[] = "+xra";                  /* symbol-specification characters */
+const char color_string[]   = "kaswrylqbfmogtnpx";     /* color-specification characters */
 
 
 void InitializeVariables ( void )
