@@ -4,7 +4,7 @@
 *
 * Plots a two-dimensional projection of three-dimensional data.
 *
-* Copyright  2008 Spencer A. Buckner
+* Copyright  2008-2009 Spencer A. Buckner
 * http://savannah.gnu.org/projects/gsegrafix
 *
 * This file is part of GSEGrafix, a scientific and engineering plotting program.
@@ -31,9 +31,10 @@
 void PlotData3d ( void )
    {
    /* Declare variables */
-   int iplot, nplots, ipoints, imesh, icontour, index_plot_types,
+   int iplot, nplots, ipoints, imesh, icontour, icolor, index_plot_types,
        npts, nx, ny, index, xindex_mesh, yindex_mesh, zindex_mesh,
-       xindex_contour, yindex_contour, zindex_contour;
+       xindex_contour, yindex_contour, zindex_contour,
+       xindex_color, yindex_color, zindex_color;
 
 
    /* Plot data */
@@ -42,6 +43,7 @@ void PlotData3d ( void )
    ipoints = 0;
    imesh = 0;
    icontour = 0;
+   icolor = 0;
    index = 0;
    xindex_mesh = 0;
    yindex_mesh = 0;
@@ -49,6 +51,9 @@ void PlotData3d ( void )
    xindex_contour = 0;
    yindex_contour = 0;
    zindex_contour = 0;
+   xindex_color = 0;
+   yindex_color = 0;
+   zindex_color = 0;
    for ( iplot=1; iplot<=nplots; iplot++ )
       {
       if ( strcmp(&plot_types[index_plot_types], "points") == 0 )
@@ -72,7 +77,7 @@ void PlotData3d ( void )
          /* Plot 3d mesh data */
          nx = nxmesh[imesh-1];
          ny = nymesh[imesh-1];
-         PlotMesh3d(iplot, xindex_mesh, yindex_mesh, zindex_mesh, nx, ny);
+         MeshPlot3d(iplot, imesh, xindex_mesh, yindex_mesh, zindex_mesh, nx, ny);
 
          /* Increment indices */
          xindex_mesh = xindex_mesh + nx;
@@ -88,7 +93,7 @@ void PlotData3d ( void )
          /* Plot 3d contour data */
          nx = nxcontour[icontour-1];
          ny = nycontour[icontour-1];
-         PlotContours3d(iplot, xindex_contour, yindex_contour, zindex_contour, nx, ny);
+         ContourPlot3d(iplot, icontour, xindex_contour, yindex_contour, zindex_contour, nx, ny);
 
          /* Increment indices */
          xindex_contour = xindex_contour + nx;
@@ -97,6 +102,23 @@ void PlotData3d ( void )
          }
 
 
+      else if ( strcmp(&plot_types[index_plot_types], "color") == 0 )
+         {
+         /* Increment plot counter */
+         icolor++;
+
+         /* Plot 3d color data */
+         nx = nxcolor[icolor-1];
+         ny = nycolor[icolor-1];
+         ColorPlot3d(iplot, xindex_color, yindex_color, zindex_color, nx, ny);
+
+         /* Increment indices */
+         xindex_color = xindex_color + nx;
+         yindex_color = yindex_color + ny;
+         zindex_color = zindex_color + nx*ny;
+         }
+
+
       /* Increment indices */
       index_plot_types = index_plot_types + 10;
       }
