@@ -147,7 +147,7 @@ void PlotEllipses ( void )
                   }
 
                /* Check line character */
-               if ( line_char != 'l' && line_char != 'd' )
+               if ( line_char != 'l' && line_char != 'd' && line_char != '.' )
                   {
                   ErrorDialog(error_str[3]);
                   FreeMemory();
@@ -199,6 +199,9 @@ void PlotEllipses ( void )
          else if ( line_char == 'd' )
             DrawLines2d(npts, &x[0],  &y[0], xmin, xmax, ymin, ymax, xscale, yscale,
                         line_color, line_width, "dashed");
+         else if ( line_char == '.' )
+            DrawLines2d(npts, &x[0],  &y[0], xmin, xmax, ymin, ymax, xscale, yscale,
+                        line_color, line_width, "dotted");
          }
 
       else if ( strncmp(line, "#####", 5) == 0 )
