@@ -4,7 +4,7 @@
 *
 * Plots 3-dimensional mesh data for truncated polygons.
 *
-* Copyright  2008 Spencer A. Buckner
+* Copyright  2008-2009 Spencer A. Buckner
 * http://savannah.gnu.org/projects/gsegrafix
 *
 * This file is part of GSEGrafix, a scientific and engineering plotting program.
@@ -28,7 +28,8 @@
 #include "gsegraf.h"
 
 
-void  PlotInterp3d ( int iplot, double xmin, double ymin, double zmin, double zmax,
+void  PlotInterp3d ( int iplot, int imesh,
+                     double xmin, double ymin, double zmin, double zmax,
                      double xscale, double yscale, double zscale,
                      double *origin, double *Ryz, guint32 *fill_color,
                      double *xpoints, double *ypoints, double *zpoints )
@@ -274,7 +275,7 @@ void  PlotInterp3d ( int iplot, double xmin, double ymin, double zmin, double zm
                                          GNOME_TYPE_CANVAS_POLYGON,
                                          "points", points_polygon,
                                          "fill_color_rgba", color_polygon,
-                                         "outline_color_rgba", 0x000000FF,
+                                         "outline_color_rgba", meshcolors[imesh-1],
                                          "width_pixels", 1,
                                          NULL);
          }
@@ -289,7 +290,7 @@ void  PlotInterp3d ( int iplot, double xmin, double ymin, double zmin, double zm
                                          GNOME_TYPE_CANVAS_POLYGON,
                                          "points", points_polygon,
                                          "fill_color_rgba", fill_color[ifill],
-                                         "outline_color_rgba", 0x000000FF,
+                                         "outline_color_rgba", meshcolors[imesh-1],
                                          "width_pixels", 1,
                                          NULL);
          }
@@ -306,6 +307,7 @@ void  PlotInterp3d ( int iplot, double xmin, double ymin, double zmin, double zm
                                       GNOME_TYPE_CANVAS_POLYGON,
                                       "points", points_polygon,
                                       "fill_color_rgba", fill_color[ifill],
+                                      "outline_color_rgba", fill_color[ifill],
                                       NULL);
 
       points_line = gnome_canvas_points_new(3);
