@@ -345,7 +345,7 @@ void PlotLines ( void )
                   }
 
                /* Check line type */
-               if ( line_char != 'l' && line_char != 'd' )
+               if ( line_char != 'l' && line_char != 'd' && line_char != '.' )
                   {
                   ErrorDialog(error_str[3]);
                   FreeMemory();
@@ -482,6 +482,70 @@ void PlotLines ( void )
                   }
                }
             }
+
+         else if ( line_char == '.' )
+            {
+            if ( strcmp(p_plot_param->axis_type, "linear")    == 0 ||
+                 strcmp(p_plot_param->axis_type, "semilogx")  == 0 ||
+                 strcmp(p_plot_param->axis_type, "semilogy")  == 0 ||
+                 strcmp(p_plot_param->axis_type, "loglog")    == 0 )
+               {
+               if ( Clip2d(xmin, xmax, ymin, ymax, &line_coords[0]) == 1 )
+                  {
+                  points = gnome_canvas_points_new(2);
+                  points->coords[0] = x1_box + (line_coords[0] - xmin)*xscale;
+                  points->coords[1] = y2_box - (line_coords[1] - ymin)*yscale;
+                  points->coords[2] = x1_box + (line_coords[2] - xmin)*xscale;
+                  points->coords[3] = y2_box - (line_coords[3] - ymin)*yscale;
+                  DrawDottedLine(points, line_color, line_width);
+                  gnome_canvas_points_unref(points);
+                  }
+               }
+
+            else if ( strcmp(p_plot_param->axis_type, "polar") == 0 )
+               {
+               if ( ClipPolar(rmin, rmax, &line_coords[0]) == 1 )
+                  {
+                  points = gnome_canvas_points_new(2);
+                  points->coords[0] = xorigin + (line_coords[1] - rmin)*cos(line_coords[0])*rscale;
+                  points->coords[1] = yorigin - (line_coords[1] - rmin)*sin(line_coords[0])*rscale;
+                  points->coords[2] = xorigin + (line_coords[3] - rmin)*cos(line_coords[2])*rscale;
+                  points->coords[3] = yorigin - (line_coords[3] - rmin)*sin(line_coords[2])*rscale;
+                  DrawDottedLine(points, line_color, line_width);
+                  gnome_canvas_points_unref(points);
+                  }
+               }
+
+            else if ( strcmp(p_plot_param->axis_type, "3d") == 0 )
+               {
+               if ( Clip3d(xmin, xmax, ymin, ymax, zmin, zmax, &line_coords[0]) == 1 )
+                  {
+                  r1[0] = (line_coords[0] - xmin)*xscale;
+                  r1[1] = (line_coords[1] - ymin)*yscale;
+                  r1[2] = (line_coords[2] - zmin)*zscale;
+
+                  r2[0] = (line_coords[3] - xmin)*xscale;
+                  r2[1] = (line_coords[4] - ymin)*yscale;
+                  r2[2] = (line_coords[5] - zmin)*zscale;
+
+                  p = multiply_mv(Ryz, r1);
+                  for ( i=1; i<=3; i++, p++ )
+                     r1[i-1] = *p;
+
+                  p = multiply_mv(Ryz, r2);
+                  for ( i=1; i<=3; i++, p++ )
+                     r2[i-1] = *p;
+
+                  points = gnome_canvas_points_new(2);
+                  points->coords[0] = origin[1] + r1[1];
+                  points->coords[1] = origin[2] - r1[2];
+                  points->coords[2] = origin[1] + r2[1];
+                  points->coords[3] = origin[2] - r2[2];
+                  DrawDottedLine(points, line_color, line_width);
+                  gnome_canvas_points_unref(points);
+                  }
+               }
+            }
          }
 
       else if ( strncmp(line, "#####", 5) == 0 )
