@@ -94,6 +94,8 @@ void PolarPlot ( void )
                DrawLine(points, gridcolor, 1);
             else if ( gridchar1 == 'd' )
                DrawDashedLine(points, gridcolor, 1);
+            else if ( gridchar1 == '.' )
+               DrawDottedLine(points, gridcolor, 1);
             }
          gnome_canvas_points_unref(points);
          }
@@ -125,6 +127,11 @@ void PolarPlot ( void )
                radius_grid = (p_ticklabels->yvalues[i-1] - rmin)*rscale;
                DrawDashedCircle(xorigin, yorigin, radius_grid, gridcolor);
                }
+            else if ( gridchar1 == '.' )
+               {
+               radius_grid = (p_ticklabels->yvalues[i-1] - rmin)*rscale;
+               DrawDottedCircle(xorigin, yorigin, radius_grid, gridcolor);
+               }
             }
          }
       }
@@ -440,6 +447,11 @@ void PolarPlot ( void )
          DrawLineSegmentsPolar(iplot, index, npts, xorigin, yorigin, rmin, rmax, rscale, 'd');
 
 
+      /* Draw dashed lines */
+      else if ( stylechar1[iplot-1] == '.' )
+         DrawLineSegmentsPolar(iplot, index, npts, xorigin, yorigin, rmin, rmax, rscale, '.');
+
+
       /* Draw symbols in symbol_string1 ("cCtTsSiIpPhH") */
       else if ( (pchar = strchr(symbol_string1, stylechar1[iplot-1])) != NULL )
          {
@@ -549,6 +561,8 @@ void DrawLineSegmentsPolar ( int iplot, int index, int npts,
       strcpy(linetype, "solid");
    else if ( linechar == 'd' )
       strcpy(linetype, "dashed");
+   else if ( linechar == '.' )
+      strcpy(linetype, "dotted");
 
 
    /* Draw all line segments except last */
@@ -585,8 +599,7 @@ void DrawLineSegmentsPolar ( int iplot, int index, int npts,
    }
 
 
-void DrawDashedCircle ( double xorigin, double yorigin, double radius,
-                        guint32 fill_color_rgba)
+void DrawDashedCircle ( double xorigin, double yorigin, double radius, guint32 fill_color_rgba)
    {
    /* Declare variables */
    int i, j, ndashes;
@@ -595,37 +608,77 @@ void DrawDashedCircle ( double xorigin, double yorigin, double radius,
    GnomeCanvasPoints *points;
 
 
-   /* Draw dashed circle */
+   /* Check radius */
    if ( radius == 0.0 )
       return;
-   else
+
+
+   /* Draw dashed circle */
+   ndashes = roundint(2.0*pi*radius/(dash + space_dash));
+   dtheta1 = 2.0*pi/ndashes;
+   dtheta2 = 0.5*pi*dash/(ndashes*(dash + space_dash));
+
+   points = gnome_canvas_points_new(5);
+
+   for ( i=1; i<=ndashes; i++ )
       {
-      ndashes = roundint(2.0*pi*radius/(dash + space));
-      dtheta1 = 2.0*pi/ndashes;
-      dtheta2 = 0.5*pi*dash/(ndashes*(dash + space));
-
-      points = gnome_canvas_points_new(5);
-
-      for ( i=1; i<=ndashes; i++ )
+      theta1 = (i - 1)*dtheta1;
+      points->coords[0] = xorigin + radius*cos(theta1);
+      points->coords[1] = yorigin - radius*sin(theta1);
+      for ( j=1; j<=4; j++ )
          {
-         theta1 = (i - 1)*dtheta1;
-         points->coords[0] = xorigin + radius*cos(theta1);
-         points->coords[1] = yorigin - radius*sin(theta1);
-         for ( j=1; j<=4; j++ )
-            {
-            theta2 = theta1 + j*dtheta2;
-            points->coords[2*j]   = xorigin + radius*cos(theta2);
-            points->coords[2*j+1] = yorigin - radius*sin(theta2);
-            }
-
-         line = gnome_canvas_item_new(group,
-                                      GNOME_TYPE_CANVAS_LINE,
-                                      "points", points,
-                                      "fill_color_rgba", fill_color_rgba,
-                                      "width_pixels", 1,
-                                      NULL);
+         theta2 = theta1 + j*dtheta2;
+         points->coords[2*j]   = xorigin + radius*cos(theta2);
+         points->coords[2*j+1] = yorigin - radius*sin(theta2);
          }
 
-      gnome_canvas_points_unref(points);
+      line = gnome_canvas_item_new(group,
+                                   GNOME_TYPE_CANVAS_LINE,
+                                   "points", points,
+                                   "fill_color_rgba", fill_color_rgba,
+                                   "width_pixels", 1,
+                                   NULL);
+      }
+
+   gnome_canvas_points_unref(points);
+   }
+
+
+void DrawDottedCircle ( double xorigin, double yorigin, double radius, guint32 fill_color_rgba)
+   {
+   /* Declare variables */
+   int i, npoints, ndots;
+   double theta[361], length[361], length_total, inc, inc_calc, length_interp, theta_interp;
+
+
+   /* Check radius */
+   if ( radius == 0 )
+      return;
+
+
+   /* Calculate circle length */
+   npoints = 361;
+   for ( i=1; i<=npoints; i++ )
+      {
+      theta[i-1] = (i - 1)*pi/180.0;
+      length[i-1] = radius*theta[i-1];
+      }
+   length_total = length[npoints-1];
+
+
+   /* Calculate number of dots */
+   inc = space_dot + 1.0;
+   ndots = roundint(length_total/inc + 1.0);
+   inc_calc = length_total/(ndots - 1);
+
+
+   /* Interpolate and draw dots */
+   for ( i=1; i<ndots; i++ )
+      {
+      length_interp = length[0] + (i - 1)*inc_calc;
+      interp1(npoints, 1, length, theta, &length_interp, &theta_interp);
+      DrawCircle(xorigin+radius*cos(theta_interp), yorigin-radius*sin(theta_interp),
+                 fill_color_rgba, fill_color_rgba, 1);
       }
    }
+
