@@ -14,7 +14,7 @@
 *
 * Functions for View menu items.
 *
-* Copyright  2008 Spencer A. Buckner
+* Copyright  2008-2009 Spencer A. Buckner
 * http://savannah.gnu.org/projects/gsegrafix
 *
 * This file is part of GSEGrafix, a scientific and engineering plotting program.
@@ -94,16 +94,16 @@ void ViewAxesHandler ( void )
 
    else if ( strcmp(p_plot_param->axis_type, "semilogx") == 0 )
       sprintf(string, "%g %g %g %g",
-              pow(10.0, xmin), pow(10.0, xmax), ymin, ymax);
+              pow(10.0, floor(xmin)), pow(10.0, ceil(xmax)), ymin, ymax);
 
    else if ( strcmp(p_plot_param->axis_type, "semilogy") == 0 )
       sprintf(string, "%g %g %g %g",
-              xmin, xmax, pow(10.0, ymin), pow(10.0, ymax));
+              xmin, xmax, pow(10.0, floor(ymin)), pow(10.0, ceil(ymax)));
 
    else if ( strcmp(p_plot_param->axis_type, "loglog") == 0 )
       sprintf(string, "%g %g %g %g",
-              pow(10.0, xmin), pow(10.0, xmax),
-              pow(10.0, ymin), pow(10.0, ymax));
+              pow(10.0, floor(xmin)), pow(10.0, ceil(xmax)),
+              pow(10.0, floor(ymin)), pow(10.0, ceil(ymax)));
 
    else if ( strcmp(p_plot_param->axis_type, "polar") == 0 )
       sprintf(string, "%g %g", ymin, ymax);
@@ -268,7 +268,7 @@ void ViewAxesCallback ( GtkEntry *entry_box )
 
       /* Destroy old canvas group */
       flag = 0;
-      if ( flag_coords_display == 1 )
+      if ( coords_display_flag == 1 )
          {
          ViewCoordsDisplayHandler();
          flag = 1;
@@ -305,9 +305,9 @@ void ViewAxesCallback ( GtkEntry *entry_box )
          if ( strcmp(p_plot_param->axis_type, "linear") == 0 &&
               strcmp(p_plot_param->axis_scale, "equal") == 0 )
             AxesEqual(0);
-         DrawGrid();
+         DrawGrid2d();
          DrawGridLog();
-         PlotData();
+         PlotData2d();
          if ( strcmp(p_plot_param->axis_type, "linear") == 0 )
             {
             PlotRectangles();
@@ -315,7 +315,7 @@ void ViewAxesCallback ( GtkEntry *entry_box )
             }
          PlotLines();
          PlotSymbols();
-         DrawTickLabels();
+         DrawTickLabels2d();
          DrawTickLabelsLog();
          DrawAxisLabels();
          DrawLegend();
@@ -489,7 +489,7 @@ void ViewLabelHandler ( void )
 
    /* Reset flag */
    window = (GtkWidget *) p_window_data->window;
-   if ( flag_contour_labels == 0 )
+   if ( contour_labels_flag == 0 )
       {
       /* Get number of contour plots */
       nplots = p_plot_param->nplots;
@@ -500,7 +500,7 @@ void ViewLabelHandler ( void )
       ncontour_plots = icount;
 
       /* Set cursor and initialize text canvas item */
-      flag_contour_labels = 1;
+      contour_labels_flag = 1;
       icontour_plots = 1;
       cursor = gdk_cursor_new(GDK_CROSSHAIR);
       gdk_window_set_cursor((GdkWindow *) window->window, cursor);
@@ -518,15 +518,15 @@ void ViewLabelHandler ( void )
       gtk_widget_set_sensitive(axes_menu_item, FALSE);
       }
 
-   else if ( flag_contour_labels == 1 )
+   else if ( contour_labels_flag == 1 )
       {
       icontour_plots = 1;
-      flag_contour_labels = 0;
+      contour_labels_flag = 0;
       if ( gdk_pointer_is_grabbed() == TRUE )
          gdk_pointer_ungrab(GDK_CURRENT_TIME);
       if ( G_IS_OBJECT(GTK_OBJECT(text_contour_data)) )
          gtk_object_destroy(GTK_OBJECT(text_contour_data));
-      if ( flag_coords_display == 0 )
+      if ( coords_display_flag == 0 )
          gdk_window_set_cursor((GdkWindow *) window->window, NULL);
       gtk_widget_set_sensitive(axes_menu_item, TRUE);
       }
@@ -658,9 +658,9 @@ void ViewCoordsDisplayHandler ( void )
 
    /* Reset flag */
    window = (GtkWidget *) p_window_data->window;
-   if ( flag_coords_display == 0 )
+   if ( coords_display_flag == 0 )
       {
-      flag_coords_display = 1;
+      coords_display_flag = 1;
 
       /* Set cursor and initialize text canvas item */
       cursor = gdk_cursor_new(GDK_CROSSHAIR);
@@ -676,14 +676,14 @@ void ViewCoordsDisplayHandler ( void )
                                                   NULL);
       }
 
-   else if ( flag_coords_display == 1 )
+   else if ( coords_display_flag == 1 )
       {
-      flag_coords_display = 0;
+      coords_display_flag = 0;
       if ( gdk_pointer_is_grabbed() == TRUE )
          gdk_pointer_ungrab(GDK_CURRENT_TIME);
       if ( G_IS_OBJECT(GTK_OBJECT(text_xy_coords_data)) )
          gtk_object_destroy(GTK_OBJECT(text_xy_coords_data));
-      if ( flag_contour_labels == 0 )
+      if ( contour_labels_flag == 0 )
          gdk_window_set_cursor((GdkWindow *) window->window, NULL);
       }
 
