@@ -4,7 +4,7 @@
 *
 * Causes plot to zoom out to original plot.
 *
-* Copyright  2008 Spencer A. Buckner
+* Copyright  2008-2009 Spencer A. Buckner
 * http://savannah.gnu.org/projects/gsegrafix
 *
 * This file is part of GSEGrafix, a scientific and engineering plotting program.
@@ -61,9 +61,9 @@ void ZoomOut ( void )
       p_ticklabels->zoffset2 = p_ticklabels->zoffset2_ref;
 
       /* Draw plot */
-      DrawGrid();
+      DrawGrid2d();
       DrawGridLog();
-      PlotData();
+      PlotData2d();
       if ( strcmp(p_plot_param->axis_type, "linear") == 0 )
          {
          PlotRectangles();
@@ -71,7 +71,7 @@ void ZoomOut ( void )
          }
       PlotLines();
       PlotSymbols();
-      DrawTickLabels();
+      DrawTickLabels2d();
       DrawTickLabelsLog();
       DrawAxisLabels();
       DrawLegend();
