@@ -118,7 +118,7 @@ int flag_linear, flag_logx, flag_logy, flag_loglog, flag_polar, flag_3d,
 
 
 /* Declare tick-mark and dashed-line variables */
-double tick_major, tick_minor, dash, space;
+double tick_major, tick_minor, dash, space_dash, space_dot;
 
 
 /* Declare gnome canvas group pointers */
@@ -277,6 +277,7 @@ void     DrawLines3d ( int npts, double *x, double *y, double *z, double *origin
 /* DrawSymbols.c */
 void     DrawLine ( GnomeCanvasPoints *points, guint32 fill_color_rgba, unsigned int line_width );
 void     DrawDashedLine ( GnomeCanvasPoints *points, guint32 fill_color_rgba, unsigned int line_width );
+void     DrawDottedLine ( GnomeCanvasPoints *points, guint32 fill_color_rgba, unsigned int size );
 void     DrawCircle ( double x, double y, guint32 fill_color_rgba, guint32 outline_color_rgba, unsigned int size );
 void     DrawTriangle ( double x, double y, guint32 fill_color_rgba, guint32 outline_color_rgba, unsigned int size );
 void     DrawSquare ( double x, double y, guint32 fill_color_rgba, guint32 outline_color_rgba, unsigned int size );
@@ -412,6 +413,7 @@ void     DrawLineSegmentsPolar ( int iplot, int index, int npts,
                                  double xorigin, double yorigin, double rmin, double rmax,
                                  double rscale, int linechar );
 void     DrawDashedCircle ( double xorigin, double yorigin, double radius, guint32 fill_color_rgba );
+void     DrawDottedCircle ( double xorigin, double yorigin, double radius, guint32 fill_color_rgba );
 
 void     ReadParamFile ( void );
 
